.. _community_getting_started:

****************
Getting started
****************

Welcome and thank you for getting more involved with the Ansible community. Here are some ways you can get started.

.. toctree::
   :maxdepth: 2

   code_of_conduct
   contributor_license_agreement
   communication
   how_can_I_help



Other ways to get involved
==========================

Here are some other ways to connect with the Ansible community:

* Find an `Ansible Meetup near me <https://www.meetup.com/topics/ansible/>`_
   communication
* Learn more about Ansible:

  * `Read books <https://www.ansible.com/resources/ebooks>`_.
  * `Get certified <https://www.ansible.com/products/training-certification>`_.
  * `Attend events <https://www.ansible.com/community/events>`_.
  * `Review getting started guides <https://www.ansible.com/resources/get-started>`_.
  * `Watch videos <https://www.ansible.com/resources/videos>`_ - includes Ansible Automates, AnsibleFest & webinar recordings.
* See where `new releases are announced <https://groups.google.com/forum/#!forum/ansible-announce>`_
